@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: main.cc 420 2007-06-22 15:29:58Z murrayc $ */
+/* $Id: main.cc 750 2008-12-12 01:09:55Z jjongsma $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -24,7 +24,6 @@
 #include <glibmm/wrap.h>
 #include <glibmm/iochannel.h>
 
-#include <glib/gmessages.h>
 #include <algorithm>
 
 GLIBMM_USING_STD(min)
@@ -311,6 +310,12 @@ sigc::connection SignalTimeout::connect(const sigc::slot<bool>& slot,
   return connection;
 }
 
+void SignalTimeout::connect_once(const sigc::slot<void>& slot, 
+                                 unsigned int interval, int priority)
+{
+    connect(sigc::bind_return(slot, false), interval, priority);
+}
+
 /* Note that this is our equivalent of g_timeout_add_seconds(). */
 sigc::connection SignalTimeout::connect_seconds(const sigc::slot<bool>& slot,
                                         unsigned int interval, int priority)
@@ -334,6 +339,12 @@ sigc::connection SignalTimeout::connect_seconds(const sigc::slot<bool>& slot,
   return connection;
 }
 
+void SignalTimeout::connect_seconds_once(const sigc::slot<void>& slot, 
+                                         unsigned int interval, int priority)
+{
+    connect_seconds(sigc::bind_return(slot, false), interval, priority);
+}
+
 SignalTimeout signal_timeout()
 {
   return SignalTimeout(0); // 0 means default context
@@ -369,6 +380,11 @@ sigc::connection SignalIdle::connect(const sigc::slot<bool>& slot, int priority)
   return connection;
 }
 
+void SignalIdle::connect_once(const sigc::slot<void>& slot, int priority)
+{
+    connect(sigc::bind_return(slot, false), priority);
+}
+
 SignalIdle signal_idle()
 {
   return SignalIdle(0); // 0 means default context
